##########################################################################
# setup script for pyFLTK, using mingw compiler on Windows
#
from distutils.core import setup, Extension
import os, sys, string

# these settings will read setup information from the environment.
# instead of this, the relevant paths can be set directly here:
#
fltk_dir = ""
opengl_dir = ""
# this will be overrridden by environment variables:
try:
    fltk_dir = os.environ['FLTK_HOME']
except:
    pass
try:
    opengl_dir = os.environ['OPENGL_HOME']
except:
    pass
# do not edit beyond this point
###########################################################################

# create proper paths
fltk_lib_dir = os.path.join(fltk_dir, 'lib')

print "platform = ", sys.platform, os.name

# whatever is system dependent
def_list = [('WIN32', '1')]
lib_dir_list = [fltk_lib_dir]
lib_list = ["fltk", "fltk_images", "fltk_forms", "fltk_gl", "kernel32", "user32", "gdi32", "winspool", "comdlg32", "Comctl32", "advapi32", "shell32", "ole32", "oleaut32", "uuid", "odbc32", "odbccp32", "wsock32", "opengl32", "stdc++"]

# module declarations
module1 = Extension('_fltk',
		    define_macros=def_list,
		    include_dirs = [fltk_dir, './src', './contrib'],
                    sources = ['./python/fltk_wrap.cpp', './contrib/ListSelect.cpp', './contrib/Fl_Table_Row.cxx', './contrib/Fl_Table.cxx'],
		    library_dirs=lib_dir_list,
          	    libraries=lib_list)


setup (name = 'pyFltk',
       version = '1.1b2',
       author = 'Andreas Held',
       author_email = 'a.held@computer.org',
       url = '//http:/pyfltk.sourceforge.net',
       description = 'This is a Python wrapper for the FLTK',
       ext_modules = [module1],
       py_modules = ["fltk"])


